==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebRadioGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioGroupDescription } from "./WebRadioGroupDescription";
/**
 * @hidden
 */
export let WebRadioGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRadioGroupDescriptionMetadata extends Base {
        static b(a) {
            if (WebRadioGroupDescriptionMetadata.a == null) {
                WebRadioGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRadioGroupDescriptionMetadata.c(WebRadioGroupDescriptionMetadata.a);
            }
            if (a.k(WebRadioGroupDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebRadioGroupDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RadioGroup");
            a.item("__tagNameWC", "String:igc-radio-group");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Alignment", "ExportedType:string:RadioGroupAlignment");
            a.item("Alignment@stringUnion", "WebComponents;React");
            a.item("Alignment@names", "Horizontal;Vertical");
        }
        static d(a) {
            WebRadioGroupDescriptionMetadata.b(a);
            a.ad("WebRadioGroup", () => new WebRadioGroupDescription());
            a.ac("WebRadioGroup", WebRadioGroupDescriptionMetadata.a);
        }
    }
    WebRadioGroupDescriptionMetadata.$t = markType(WebRadioGroupDescriptionMetadata, 'WebRadioGroupDescriptionMetadata');
    WebRadioGroupDescriptionMetadata.a = null;
    return WebRadioGroupDescriptionMetadata;
})();

==> igniteui-angular-core-19.0.1.tgz: package/esm2015/lib/WebRadioGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebRadioChangeEventArgsDescriptionMetadata } from "./WebRadioChangeEventArgsDescriptionMetadata";
import { WebRadioGroupDescription } from "./WebRadioGroupDescription";
/**
 * @hidden
 */
export let WebRadioGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRadioGroupDescriptionMetadata extends Base {
        static b(a) {
            if (WebRadioGroupDescriptionMetadata.a == null) {
                WebRadioGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRadioGroupDescriptionMetadata.c(WebRadioGroupDescriptionMetadata.a);
            }
            if (a.k(WebRadioGroupDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebRadioGroupDescriptionMetadata.a);
            WebRadioChangeEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:RadioGroup");
            a.item("__tagNameWC", "String:igc-radio-group");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Alignment", "ExportedType:string:RadioGroupAlignment");
            a.item("Alignment@stringUnion", "WebComponents;React");
            a.item("Alignment@names", "Vertical;Horizontal");
            a.item("DefaultValue", "String");
            a.item("Name", "String");
            a.item("Value", "String");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebRadioGroupDescriptionMetadata.b(a);
            a.ae("WebRadioGroup", () => new WebRadioGroupDescription());
            a.ad("WebRadioGroup", WebRadioGroupDescriptionMetadata.a);
        }
    }
    WebRadioGroupDescriptionMetadata.$t = markType(WebRadioGroupDescriptionMetadata, 'WebRadioGroupDescriptionMetadata');
    WebRadioGroupDescriptionMetadata.a = null;
    return WebRadioGroupDescriptionMetadata;
})();
